@@ -108,14 +108,29 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *cmd,
 
 	fd=createconnection_tcp(http_host, http_port);
 	fp=fdopen(fd, "r+");
+#if 0
 	/* TODO:  Change this to POST */
 	fprintf(fp, "GET http://%s:%i%s?cmd=%s&session=%s&dest=%s&data=%s&ts=%i HTTP/1.0\n\n", http_host, http_port, hex_path, hex_cmd, hex_session, hex_dest, hex_data, (unsigned int) time(NULL));
-	PRINTERR("GET http://%s:%i%s?cmd=%s&session=%s&dest=%s&data=%s&ts=%i HTTP/1.0\n\n", http_host, http_port, hex_path, hex_cmd, hex_session, hex_dest, hex_data, (unsigned int) time(NULL));
+#endif
+	snprintf(buf, sizeof(buf), "cmd=%s&session=%s&dest=%s&data=%s&ts=%i", hex_cmd, hex_session, hex_dest, hex_data, (unsigned int) time(NULL));
+	buf[sizeof(buf)-1]='\0';
+	fprintf(fp, "POST %s HTTP/1.0\r\nHost: %s\r\nContent-length: %i\r\n\r\n%s", hex_path, http_host, strlen(buf), buf);
+	PRINTERR("POST http://%s:%i%s?%s HTTP/1.0\n", http_host, http_port, hex_path, buf);
 	fflush(fp);
 
 	if (status) *status=0;
 	if (datalen) *datalen=0;
 	if (fgets(buf, sizeof(buf), fp)==NULL) return(NULL);
+	if (strstr(buf,"HTTP/1.1 40")) {
+		PRINTERR("File not available error, %s", buf);
+		if (hex_cmd) free(hex_cmd);
+		if (hex_session) free(hex_session);
+		if (hex_data) free(hex_data);
+		if (hex_dest) free(hex_dest);
+		if (hex_path) free(hex_path);
+		fclose(fp);
+		return(NULL);
+	}
 	if (!strstr(buf, "HTTP/1.1 200 ")) {
 		PRINTERR("Invalid response, %s", buf);
 		if (hex_cmd) free(hex_cmd);
@@ -143,12 +158,14 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *cmd,
 			datalen_loc|=fgetc(fp);
 			if (datalen_loc>16384) continue;
 			if (datalen_loc) {
+				PRINTERR("Now expecting %i bytes of data.", datalen_loc);
 				retbuf=malloc(datalen_loc);
 				datalen_loc=fread(retbuf, 1, datalen_loc, fp);
 				PRINTERR("[%i]%s", datalen_loc, retbuf);
 			}
 			if (datalen) *datalen=datalen_loc;
-			continue;
+			PRINTERR("We got all that we want, let's get outta here.");
+			break;
 		}
 		PRINTERR("buf=%s", buf);
 	}
