@@ -26,15 +26,18 @@
 
 #ifdef DEBUG
 #define PRINT_LINE fprintf(stderr, "%s:%i:%s(): ", __FILE__, __LINE__, __func__); 
-#define PRINTERR(x...) { PRINT_LINE; fprintf(stderr, x); fprintf(stderr, "\n"); }
-#define PERROR(x) { PRINT_LINE; perror(x); }
+#define PRINTERR(x...) { PRINT_LINE; fprintf(stderr, x); fprintf(stderr, "\n"); fflush(stderr); }
+#define PERROR(x) { PRINT_LINE; perror(x); fflush(stderr); }
+#define DPERROR(x) PERROR(x)
+#define CHECKPOINT PRINTERR("*** CHECKPOINT REACHED ***")
 #else
 #define PRINT_LINE /**/
 #define PRINTERR(x...) /**/
 #define PERROR(x) perror(x);
-
+#define DPERROR(x) /**/
+#define CHECKPOINT /**/
 #endif
 
-#define TCPCGI_VERSION "0.0.7"
+#define TCPCGI_VERSION "0.1.3"
 
 #endif
